import { OID } from "@postgresql-typed/oids";
import { arrayParser, arraySerializer, Bit, BitVarying, Boolean, Box, ByteA, Character, CharacterVarying, Circle, Date, DateMultiRange, DateRange, Float4, Float8, Int2, Int4, Int4MultiRange, Int4Range, Int8, Int8MultiRange, Int8Range, Interval, JSON, Line, LineSegment, Money, Name, OID as OIDClass, Path, Point, Polygon, Text, Time, Timestamp, TimestampMultiRange, TimestampRange, TimestampTZ, TimestampTZMultiRange, TimestampTZRange, TimeTZ, UUID, } from "../index.js";
import { parser } from "./parser.js";
import { serializer } from "./serializer.js";
export const defaultParserMappings = {
    [OID.bytea]: {
        parse: parser(ByteA),
        serialize: serializer(ByteA),
    },
    [OID._bytea]: {
        parse: arrayParser(ByteA),
        serialize: arraySerializer(ByteA, undefined, "\\"),
    },
    [OID.bit]: {
        parse: parser(Bit),
        serialize: serializer(Bit),
    },
    [OID._bit]: {
        parse: arrayParser(Bit),
        serialize: arraySerializer(Bit, ","),
    },
    [OID.varbit]: {
        parse: parser(BitVarying),
        serialize: serializer(BitVarying),
    },
    [OID._varbit]: {
        parse: arrayParser(BitVarying),
        serialize: arraySerializer(BitVarying, ","),
    },
    [OID.bool]: {
        // eslint-disable-next-line @typescript-eslint/ban-types
        parse: parser(Boolean),
        // eslint-disable-next-line @typescript-eslint/ban-types
        serialize: serializer(Boolean),
    },
    [OID._bool]: {
        // eslint-disable-next-line @typescript-eslint/ban-types
        parse: arrayParser(Boolean),
        // eslint-disable-next-line @typescript-eslint/ban-types
        serialize: arraySerializer(Boolean, ","),
    },
    [OID.char]: {
        parse: parser(Character),
        serialize: serializer(Character),
    },
    [OID._char]: {
        parse: arrayParser(Character),
        serialize: arraySerializer(Character, ","),
    },
    [OID.bpchar]: {
        parse: parser(Character),
        serialize: serializer(Character),
    },
    [OID._bpchar]: {
        parse: arrayParser(Character),
        serialize: arraySerializer(Character, ","),
    },
    [OID.varchar]: {
        parse: parser(CharacterVarying),
        serialize: serializer(CharacterVarying),
    },
    [OID._varchar]: {
        parse: arrayParser(CharacterVarying),
        serialize: arraySerializer(CharacterVarying, ","),
    },
    [OID.name]: {
        parse: parser(Name),
        serialize: serializer(Name),
    },
    [OID._name]: {
        parse: arrayParser(Name),
        serialize: arraySerializer(Name, ","),
    },
    [OID.text]: {
        parse: parser(Text),
        serialize: serializer(Text),
    },
    [OID._text]: {
        parse: arrayParser(Text),
        serialize: arraySerializer(Text, ","),
    },
    [OID.date]: {
        parse: parser(Date),
        serialize: serializer(Date),
    },
    [OID._date]: {
        parse: arrayParser(Date),
        serialize: arraySerializer(Date, ","),
    },
    [OID.datemultirange]: {
        parse: parser(DateMultiRange),
        serialize: serializer(DateMultiRange),
    },
    [OID._datemultirange]: {
        parse: arrayParser(DateMultiRange),
        serialize: arraySerializer(DateMultiRange),
    },
    [OID.daterange]: {
        parse: parser(DateRange),
        serialize: serializer(DateRange),
    },
    [OID._daterange]: {
        parse: arrayParser(DateRange),
        serialize: arraySerializer(DateRange),
    },
    [OID.interval]: {
        parse: parser(Interval),
        serialize: serializer(Interval),
    },
    [OID._interval]: {
        parse: arrayParser(Interval),
        serialize: arraySerializer(Interval),
    },
    [OID.time]: {
        parse: parser(Time),
        serialize: serializer(Time),
    },
    [OID._time]: {
        parse: arrayParser(Time),
        serialize: arraySerializer(Time, ","),
    },
    [OID.timestamp]: {
        parse: parser(Timestamp),
        serialize: serializer(Timestamp),
    },
    [OID._timestamp]: {
        parse: arrayParser(Timestamp),
        serialize: arraySerializer(Timestamp),
    },
    [OID.tsmultirange]: {
        parse: parser(TimestampMultiRange),
        serialize: serializer(TimestampMultiRange),
    },
    [OID._tsmultirange]: {
        parse: arrayParser(TimestampMultiRange),
        serialize: arraySerializer(TimestampMultiRange),
    },
    [OID.tsrange]: {
        parse: parser(TimestampRange),
        serialize: serializer(TimestampRange),
    },
    [OID._tsrange]: {
        parse: arrayParser(TimestampRange),
        serialize: arraySerializer(TimestampRange),
    },
    [OID.timestamptz]: {
        parse: parser(TimestampTZ),
        serialize: serializer(TimestampTZ),
    },
    [OID._timestamptz]: {
        parse: arrayParser(TimestampTZ),
        serialize: arraySerializer(TimestampTZ),
    },
    [OID.tstzmultirange]: {
        parse: parser(TimestampTZMultiRange),
        serialize: serializer(TimestampTZMultiRange),
    },
    [OID._tstzmultirange]: {
        parse: arrayParser(TimestampTZMultiRange),
        serialize: arraySerializer(TimestampTZMultiRange),
    },
    [OID.tstzrange]: {
        parse: parser(TimestampTZRange),
        serialize: serializer(TimestampTZRange),
    },
    [OID._tstzrange]: {
        parse: arrayParser(TimestampTZRange),
        serialize: arraySerializer(TimestampTZRange),
    },
    [OID.timetz]: {
        parse: parser(TimeTZ),
        serialize: serializer(TimeTZ),
    },
    [OID._timetz]: {
        parse: arrayParser(TimeTZ),
        serialize: arraySerializer(TimeTZ, ","),
    },
    [OID.box]: {
        parse: parser(Box),
        serialize: serializer(Box),
    },
    [OID._box]: {
        parse: arrayParser(Box, ";"),
        serialize: arraySerializer(Box, ";"),
    },
    [OID.circle]: {
        parse: parser(Circle),
        serialize: serializer(Circle),
    },
    [OID._circle]: {
        parse: arrayParser(Circle),
        serialize: arraySerializer(Circle),
    },
    [OID.line]: {
        parse: parser(Line),
        serialize: serializer(Line),
    },
    [OID._line]: {
        parse: arrayParser(Line),
        serialize: arraySerializer(Line),
    },
    [OID.lseg]: {
        parse: parser(LineSegment),
        serialize: serializer(LineSegment),
    },
    [OID._lseg]: {
        parse: arrayParser(LineSegment),
        serialize: arraySerializer(LineSegment),
    },
    [OID.path]: {
        parse: parser(Path),
        serialize: serializer(Path),
    },
    [OID._path]: {
        parse: arrayParser(Path),
        serialize: arraySerializer(Path),
    },
    [OID.point]: {
        parse: parser(Point),
        serialize: serializer(Point),
    },
    [OID._point]: {
        parse: arrayParser(Point),
        serialize: arraySerializer(Point),
    },
    [OID.polygon]: {
        parse: parser(Polygon),
        serialize: serializer(Polygon),
    },
    [OID._polygon]: {
        parse: arrayParser(Polygon),
        serialize: arraySerializer(Polygon),
    },
    [OID.json]: {
        parse: parser(JSON),
        serialize: serializer(JSON),
    },
    [OID._json]: {
        parse: arrayParser(JSON),
        serialize: arraySerializer(JSON),
    },
    [OID.jsonb]: {
        parse: parser(JSON),
        serialize: serializer(JSON),
    },
    [OID._jsonb]: {
        parse: arrayParser(JSON),
        serialize: arraySerializer(JSON),
    },
    [OID.money]: {
        parse: parser(Money),
        serialize: serializer(Money),
    },
    [OID._money]: {
        parse: arrayParser(Money),
        serialize: arraySerializer(Money),
    },
    [OID.float4]: {
        parse: parser(Float4),
        serialize: serializer(Float4),
    },
    [OID._float4]: {
        parse: arrayParser(Float4),
        serialize: arraySerializer(Float4, ","),
    },
    [OID.float8]: {
        parse: parser(Float8),
        serialize: serializer(Float8),
    },
    [OID._float8]: {
        parse: arrayParser(Float8),
        serialize: arraySerializer(Float8, ","),
    },
    [OID.int2]: {
        parse: parser(Int2),
        serialize: serializer(Int2),
    },
    [OID._int2]: {
        parse: arrayParser(Int2),
        serialize: arraySerializer(Int2, ","),
    },
    [OID.int4]: {
        parse: parser(Int4),
        serialize: serializer(Int4),
    },
    [OID._int4]: {
        parse: arrayParser(Int4),
        serialize: arraySerializer(Int4, ","),
    },
    [OID.int4multirange]: {
        parse: parser(Int4MultiRange),
        serialize: serializer(Int4MultiRange),
    },
    [OID._int4multirange]: {
        parse: arrayParser(Int4MultiRange),
        serialize: arraySerializer(Int4MultiRange),
    },
    [OID.int4range]: {
        parse: parser(Int4Range),
        serialize: serializer(Int4Range),
    },
    [OID._int4range]: {
        parse: arrayParser(Int4Range),
        serialize: arraySerializer(Int4Range),
    },
    [OID.int8]: {
        parse: parser(Int8),
        serialize: serializer(Int8),
    },
    [OID._int8]: {
        parse: arrayParser(Int8),
        serialize: arraySerializer(Int8, ","),
    },
    [OID.int8multirange]: {
        parse: parser(Int8MultiRange),
        serialize: serializer(Int8MultiRange),
    },
    [OID._int8multirange]: {
        parse: arrayParser(Int8MultiRange),
        serialize: arraySerializer(Int8MultiRange),
    },
    [OID.int8range]: {
        parse: parser(Int8Range),
        serialize: serializer(Int8Range),
    },
    [OID._int8range]: {
        parse: arrayParser(Int8Range),
        serialize: arraySerializer(Int8Range),
    },
    [OID.oid]: {
        parse: parser(OIDClass),
        serialize: serializer(OIDClass),
    },
    [OID._oid]: {
        parse: arrayParser(OIDClass),
        serialize: arraySerializer(OIDClass, ","),
    },
    [OID.uuid]: {
        parse: parser(UUID),
        serialize: serializer(UUID),
    },
    [OID._uuid]: {
        parse: arrayParser(UUID),
        serialize: arraySerializer(UUID, ","),
    },
};
//# sourceMappingURL=defaultParserMappings.js.map